--- ./src/http/modules/ngx_http_xslt_filter_module.c.orig	2009-11-30 21:15:10.000000000 +0800
+++ ./src/http/modules/ngx_http_xslt_filter_module.c	2010-01-27 23:45:32.000000000 +0800
@@ -48,6 +48,7 @@
     ngx_array_t          sheets;       /* ngx_http_xslt_sheet_t */
     ngx_hash_t           types;
     ngx_array_t         *types_keys;
+    ngx_array_t         *xslt_enable;
 } ngx_http_xslt_filter_loc_conf_t;
 
 
@@ -126,6 +127,8 @@
     void *conf);
 static char *ngx_http_xslt_stylesheet(ngx_conf_t *cf, ngx_command_t *cmd,
     void *conf);
+static char *ngx_http_xslt_enable(ngx_conf_t *cf, ngx_command_t *cmd,
+    void *conf);
 static void ngx_http_xslt_cleanup_dtd(void *data);
 static void ngx_http_xslt_cleanup_stylesheet(void *data);
 static void *ngx_http_xslt_filter_create_main_conf(ngx_conf_t *cf);
@@ -165,9 +167,15 @@
       offsetof(ngx_http_xslt_filter_loc_conf_t, types_keys),
       &ngx_http_xslt_default_types[0] },
 
-      ngx_null_command
-};
+    { ngx_string("xslt_enable"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_1MORE,
+      ngx_http_xslt_enable,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      offsetof(ngx_http_xslt_filter_loc_conf_t, xslt_enable),
+      NULL },
 
+    ngx_null_command
+};
 
 static ngx_http_module_t  ngx_http_xslt_filter_module_ctx = {
     NULL,                                  /* preconfiguration */
@@ -201,8 +209,7 @@
 
 
 static ngx_http_output_header_filter_pt  ngx_http_next_header_filter;
-static ngx_http_output_body_filter_pt    ngx_http_next_body_filter;
-
+static ngx_http_output_body_filter_pt    ngx_http_next_body_filter;
 
 static ngx_int_t
 ngx_http_xslt_header_filter(ngx_http_request_t *r)
@@ -225,6 +232,20 @@
         return ngx_http_next_header_filter(r);
     }
 
+#if (NGX_PCRE)
+    
+    if (conf->xslt_enable && r->headers_in.user_agent) {
+
+        if (ngx_regex_exec_array(conf->xslt_enable,
+            &r->headers_in.user_agent->value,
+            r->connection->log)
+            == NGX_DECLINED)
+        {
+            return ngx_http_next_header_filter(r);
+        }
+    }
+
+#endif     
     ctx = ngx_http_get_module_ctx(r, ngx_http_xslt_filter_module);
 
     if (ctx) {
@@ -1150,6 +1173,70 @@
     return NGX_CONF_OK;
 }
 
+
+static char *
+ngx_http_xslt_enable(ngx_conf_t *cf, ngx_command_t *cmd, void *conf)
+{
+    ngx_http_xslt_filter_loc_conf_t  *clcf = conf;
+
+#if (NGX_PCRE)
+    ngx_str_t            *value;
+    ngx_uint_t            i;
+    ngx_regex_elt_t      *re;
+    ngx_regex_compile_t   rc;
+    u_char                errstr[NGX_MAX_CONF_ERRSTR];
+
+    if (clcf->xslt_enable == NULL) {
+        clcf->xslt_enable = ngx_array_create(cf->pool, 2,
+            sizeof(ngx_regex_elt_t));
+        if (clcf->xslt_enable == NULL) {
+            return NGX_CONF_ERROR;
+        }
+    }else{
+        return NGX_CONF_ERROR;
+    }
+
+    value = cf->args->elts;
+
+    ngx_memzero(&rc, sizeof(ngx_regex_compile_t));
+
+    rc.pool = cf->pool;
+    rc.err.len = NGX_MAX_CONF_ERRSTR;
+    rc.err.data = errstr;
+
+    for (i = 1; i < cf->args->nelts; i++) {
+
+        re = ngx_array_push(clcf->xslt_enable);
+        if (re == NULL) {
+            return NGX_CONF_ERROR;
+        }
+
+        rc.pattern = value[1];
+        rc.options = NGX_REGEX_CASELESS;
+
+        if (ngx_regex_compile(&rc) != NGX_OK) {
+            ngx_conf_log_error(NGX_LOG_EMERG, cf, 0, "%V", &rc.err);
+            return NGX_CONF_ERROR;
+        }
+
+        re->regex = rc.regex;
+        re->name = value[i].data;
+
+    }
+
+    return NGX_CONF_OK;
+
+#else
+    ngx_str_t  *value;
+
+    value = cf->args->elts;
+
+    ngx_conf_log_error(NGX_LOG_EMERG, cf, 0,
+        "without PCRE library \"xslt_enable\" won't work ");
+
+    return NGX_CONF_ERROR;
+#endif
+}
 
 static void
 ngx_http_xslt_cleanup_dtd(void *data)